==> facility-2.16.18-linux-amd64.tar.zst: release-v2.16.18/packages/shared/src/utils/patientCertificates/printComponents/PatientDetailsWithBarcode.jsx <==
import React from 'react';
import { DataSection } from './DataSection';
import { View } from '@react-pdf/renderer';
import { P } from '../Typography';
import { Col } from '../Layout';
import { getDOBWithAge, getPatientWeight, getSex, getVillageName } from '../../patientAccessors';
import { PrintableBarcode } from './PrintableBarcode';
import { renderDataItems } from './renderDataItems';

export const PatientDetailsWithBarcode = ({ patient, getLocalisation }) => {
  const PATIENT_FIELDS = {
    leftCol: [
      { key: 'firstName', label: 'First name' },
      { key: 'lastName', label: 'Last name' },
      { key: 'dateOfBirth', label: 'DOB', accessor: getDOBWithAge },
      { key: 'sex', label: 'Sex', accessor: getSex },
      { key: 'villageName', label: 'Village', accessor: getVillageName },
    ],
    rightCol: [
      ...(patient.patientWeight !== undefined
        ? [
            {
              key: 'patientWeight',
              label: 'Patient weight',
              accessor: data => getPatientWeight(data, getLocalisation),
            },
          ]
        : []),
      { key: 'displayId', label: 'Patient ID' },
    ],
  };

  return (
    <DataSection title="Patient details">
      <Col>{renderDataItems(PATIENT_FIELDS.leftCol, patient, getLocalisation)}</Col>
      <Col>
        {renderDataItems(PATIENT_FIELDS.rightCol, patient, getLocalisation)}
        <View style={{ flexDirection: 'row' }}>
          <P style={{ marginTop: 9 }} fontSize={9} bold>
            Patient ID barcode:
          </P>
          <PrintableBarcode id={patient.displayId} />
        </View>
      </Col>
    </DataSection>
  );
};

==> facility-2.35.3-linux-amd64.tar.zst: release-v2.35.3/packages/shared/src/utils/patientCertificates/printComponents/PatientDetailsWithBarcode.jsx <==
import React from 'react';
import { DataSection } from './DataSection';
import { View } from '@react-pdf/renderer';
import { P } from '../Typography';
import { Col } from '../Layout';
import { getDobWithAge, getPatientWeight, getSex, getVillageName } from '../../patientAccessors';
import { useLanguageContext } from '../../pdf/languageContext';
import { PrintableBarcode } from './PrintableBarcode';
import { renderDataItems } from './renderDataItems';

export const PatientDetailsWithBarcode = ({ patient, getLocalisation }) => {
  const { getTranslation } = useLanguageContext();
  const PATIENT_FIELDS = {
    leftCol: [
      { key: 'firstName', label: 'First name' },
      { key: 'lastName', label: 'Last name' },
      { key: 'dateOfBirth', label: 'DOB', accessor: getDobWithAge },
      { key: 'sex', label: 'Sex', accessor: getSex },
      { key: 'villageName', label: 'Village', accessor: getVillageName },
    ],
    rightCol: [
      ...(patient.patientWeight !== undefined
        ? [
            {
              key: 'patientWeight',
              label: 'Patient weight',
              accessor: getPatientWeight,
            },
          ]
        : []),
      { key: 'displayId', label: 'Patient ID' },
    ],
  };

  return (
    <DataSection title="Patient details">
      <Col>{renderDataItems(PATIENT_FIELDS.leftCol, patient, getLocalisation, getTranslation)}</Col>
      <Col>
        {renderDataItems(PATIENT_FIELDS.rightCol, patient, getLocalisation, getTranslation)}
        <View style={{ flexDirection: 'row' }}>
          <P style={{ marginTop: 9 }} fontSize={9} bold>
            Patient ID barcode:
          </P>
          <PrintableBarcode id={patient.displayId} />
        </View>
      </Col>
    </DataSection>
  );
};
